@@ -1,10 +1,11 @@
 import commands
 import os.path
+import glob
 import gtk
 import gobject
 import random
 
-VERSION = "0.4.2"
+VERSION = "0.5.0"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
 # general settings
@@ -63,15 +64,26 @@ class Playlist(gtk.ListStore):
 class Song(dict):
     def __init__(self, data):
         dict.__init__(self)
-        
-        self.data = None
-        
+                
         if(isinstance(data, tuple)):
             self.data = data
-            self.uri = self.data[0]
-            self["title"] = self.data[1]
-            self["artist"] = self.data[2]
-            self["album"] = self.data[3]
+            self.uri = data[0]
+            self["title"] = data[1]
+            self["artist"] = data[2]
+            self["album"] = data[3]
         else:
             self.uri = data
+    
+    def cover_uri(self):
+        if not self.uri.startswith("file://"):
+            return None
+        
+        dir = os.path.dirname(self.uri[7:])
+
+        files = glob.iglob(dir+"/*.jpg")
+
+        try:
+            return files.next()
+        except StopIteration:
+            return None
 
