@@ -58,9 +58,10 @@ class Library(GObject):
                                           FROM songs 
                                           %s
                                           ORDER BY %s""" % (where_clause, order[config["order-by"]]), \
-                                          variables).fetchall()
-
-        return map(lambda e: Song(e), playlist)
+                                          variables)
+        
+        for s in playlist:
+            yield Song(s)
     
     def _build_where_clause(self, config):
         where_clause = ""
