@@ -90,19 +90,28 @@ class Preferences(gtk.Window):
 
         status_label = PrefLabel(_("Status"))
         lastfm.pack_start(status_label, expand=False, padding=5)
-
-        self._lastfm_status = gtk.Label( _("Connected") if scrobbler.is_connected() else _("Disconnected"))
-        lastfm.pack_start(self._lastfm_status, expand=False)
+        
+        ss = scrobbler.get_state()
+        
+        if ss == "OK":
+            state = _("Connected")
+        elif ss == "BADAUTH":
+            state = _("Wrong login data")
+        else:
+            state = _("Disconnected")
+        
+        self._lastfm_state = gtk.Label(state)
+        lastfm.pack_start(self._lastfm_state, expand=False)
 
         hbox = gtk.HBox()
         hbox.set_border_width(5)
         self._vbox.pack_start(hbox, expand=False)
         
         close = gtk.Button(stock=gtk.STOCK_CLOSE)
-        close.connect("clicked", self._on_close)
+        close.connect("clicked", self.hide_on_delete)
         hbox.pack_end(close, expand=False)
         
-        self.connect("delete-event", self._on_close)
+        self.connect("delete-event", self.hide_on_delete)
     
     def _on_lfm_user_changed(self, caller):
         self.config["lastfm-user"] = caller.get_text()
@@ -118,7 +127,3 @@ class Preferences(gtk.Window):
     
     def _on_no_rg_changed(self, caller):
         self.config["no-rg-preamp"] = caller.get_value()
-    
-    def _on_close(self, caller, event=None):
-        self.hide()
-        return True
