@@ -1,10 +1,13 @@
 import gtk
+import gtk.gdk
 import hildon
 import pango
 
 from youamp.ui.controls import Controls
 from youamp.ui.searchview import SearchView
 
+from youamp import IS_MAEMO, img_path
+
 class Menu(gtk.Menu):
     def __init__(self, config):
         gtk.Menu.__init__(self)
@@ -51,6 +54,21 @@ class Menu(gtk.Menu):
 
         self.show_all()
 
+class CoverImage(gtk.Image):
+    def __init__(self):
+        gtk.Image.__init__(self)
+        self.file = None
+        self.size = 0
+        self._pb = None
+    
+    def get_pb(self):
+        return self._pb
+    
+    def set_from_file(self, file):
+        self._pb = gtk.gdk.pixbuf_new_from_file_at_size(file, self.size, self.size)
+        self.set_from_pixbuf(self._pb)
+        self.file = file
+
 class Window(hildon.Window):
     def __init__(self, player, config, library):
         hildon.Window.__init__(self)
@@ -67,6 +85,17 @@ class Window(hildon.Window):
         vbox = gtk.VBox()
         vbox.set_spacing(5)
         
+        hbox = gtk.HBox()
+        hbox.set_spacing(5)
+        vbox.pack_start(hbox, expand=False)
+                
+        # Cover
+        self._cover = CoverImage()
+        hbox.pack_start(self._cover, expand=False)
+        
+        vbox1 = gtk.VBox()
+        hbox.pack_start(vbox1)
+        
         # Label
         self._label = gtk.Label()
         self._label.set_alignment(0, 0)
@@ -74,14 +103,17 @@ class Window(hildon.Window):
         self._label.set_ellipsize(pango.ELLIPSIZE_END)
         self._label.set_selectable(False)
         self._label.set_markup("<b><big>%s</big></b>" % _("No Track"))
-        self._label.show_all()
-        vbox.pack_start(self._label, expand=False)
+        vbox1.pack_start(self._label, expand=False)
 
         # Controls
         self._controls = Controls(self._player, self._config)
-        self._controls.show_all()
-        vbox.pack_start(self._controls, expand=False)
-
+        vbox1.pack_start(self._controls, expand=False)
+        
+        hbox.show_all()
+        
+        self._cover.size = hbox.size_request()[1]
+        self._cover.set_from_file(img_path % "audio-x-generic.png")
+        
         # View
         self.view = SearchView(self._config, self._player, self._library)
         vbox.pack_start(self.view)
@@ -102,14 +134,13 @@ class Window(hildon.Window):
     def toggle_fullscreen(self):
         if self._is_fullscreen:
             self.unfullscreen()
-            self._label.set_padding(0, 0)
         else:
             self.fullscreen()
-            self._label.set_padding(10, 10)
         
         self._is_fullscreen = not self._is_fullscreen
     
     def _update_songinfo(self, caller, newsong):
+        # text
         self.set_title("%s - %s" % (newsong["title"], newsong["artist"]))
                 
         label_txt = "<b><big>%s</big></b> %s <i>%s</i> %s <i>%s</i>" % (newsong["title"], _("by"), newsong["artist"], _("from"), newsong["album"])
@@ -119,3 +150,19 @@ class Window(hildon.Window):
             label_txt = """<span foreground="red">%s</span>""" % label_txt
         
         self._label.set_markup(label_txt)
+        
+        # image
+        cover_file = newsong.cover_uri()
+        
+        if cover_file is None:
+            cover_file = img_path % "audio-x-generic.png"
+        
+        if cover_file == self._cover.file:
+            return
+        
+        self._cover.set_from_file(cover_file)
+            
+        if not IS_MAEMO:
+            self.set_icon_list(self._cover.get_pb())
+        
+        
